@@ -25,6 +25,7 @@ use phpDocumentor\Reflection\DocBlock\Tags\Param;
 use phpDocumentor\Reflection\DocBlock\Tags\Return_;
 use phpDocumentor\Reflection\DocBlock\Tags\See;
 use phpDocumentor\Reflection\DocBlock\Tags\Since;
+use phpDocumentor\Reflection\DocBlock\Tags\Template;
 use phpDocumentor\Reflection\PseudoTypes\ConstExpression;
 use phpDocumentor\Reflection\Types\Array_;
 use phpDocumentor\Reflection\Types\Compound;
@@ -169,7 +170,7 @@ DESCRIPTION
 
     public function testMultilineTags(): void
     {
-        $docCommment = <<<DOC
+        $docComment = <<<DOC
 /**
  * This is an example of a summary.
  *
@@ -180,7 +181,7 @@ DESCRIPTION
  */
 DOC;
         $factory = DocBlockFactory::createInstance();
-        $docblock = $factory->create($docCommment);
+        $docblock = $factory->create($docComment);
 
         self::assertEquals(
             [
@@ -201,7 +202,7 @@ DOC;
 
     public function testMethodRegression(): void
     {
-        $docCommment = <<<DOC
+        $docComment = <<<DOC
 /**
  * This is an example of a summary.
  *
@@ -209,7 +210,7 @@ DOC;
  */
 DOC;
         $factory = DocBlockFactory::createInstance();
-        $docblock = $factory->create($docCommment);
+        $docblock = $factory->create($docComment);
 
         self::assertEquals(
             [
@@ -231,7 +232,7 @@ DOC;
 
     public function testInvalidTypeParamResultsInInvalidTag(): void
     {
-        $docCommment = '
+        $docComment = '
 /**
  * This is an example of a summary.
  *
@@ -239,7 +240,7 @@ DOC;
  */
 ';
         $factory = DocBlockFactory::createInstance();
-        $docblock = $factory->create($docCommment);
+        $docblock = $factory->create($docComment);
 
         self::assertEquals(
             [
@@ -257,14 +258,14 @@ DOC;
 
     public function testConstantReferenceTypes(): void
     {
-        $docCommment = <<<DOC
+        $docComment = <<<DOC
     /**
      * @return self::STATUS_*
      */
 DOC;
 
         $factory = DocBlockFactory::createInstance();
-        $docblock = $factory->create($docCommment);
+        $docblock = $factory->create($docComment);
 
         self::assertEquals(
             [
@@ -276,7 +277,7 @@ DOC;
 
     public function testRegressionWordpressDocblocks(): void
     {
-        $docCommment = <<<DOC
+        $docComment = <<<DOC
     /**
      * Install a package.
      *
@@ -311,7 +312,7 @@ DOC;
 DOC;
 
         $factory = DocBlockFactory::createInstance();
-        $docblock = $factory->create($docCommment);
+        $docblock = $factory->create($docComment);
 
         self::assertEquals(
             new DocBlock(
@@ -431,4 +432,53 @@ identifier has already been registered.',
             $docblock
         );
     }
+
+    public function testProcessTemplateTag(): void
+    {
+        $docComment = <<<DOCBLOCK
+        /** 
+         * @template T as \Type this is a description
+         * @template TDefault as \Type = \\String_ this is a description
+         */
+DOCBLOCK;
+
+        $factory = DocBlockFactory::createInstance();
+        $docblock = $factory->create($docComment);
+
+        self::assertEquals(
+            [
+                new Template(
+                    'T',
+                    new Object_(new Fqsen('\\Type')),
+                    new Mixed_(),
+                    new Description('this is a description')
+                ),
+                new Template(
+                    'TDefault',
+                    new Object_(new Fqsen('\\Type')),
+                    new Object_(new Fqsen('\\String_')),
+                    new Description('this is a description')
+                ),
+            ],
+            $docblock->getTags()
+        );
+    }
+
+    public function testParamTagDescriptionIsCorrectly(): void
+    {
+        $docComment = '
+	/**
+	 * @param int $baz Lorem ipsum dolor sit amet, consectetur adipiscing elit. Maecenas varius, tellus in cursus
+	 *     dictum, justo odio sagittis velit, id iaculis mi dui id nisi.
+	 */
+';
+
+        $factory = DocBlockFactory::createInstance();
+        $docblock = $factory->create($docComment);
+
+        $paramTags = $docblock->getTagsWithTypeByName('param')[0];
+
+        self::assertSame('Lorem ipsum dolor sit amet, consectetur adipiscing elit. Maecenas varius, tellus in cursus
+dictum, justo odio sagittis velit, id iaculis mi dui id nisi.', (string) $paramTags->getDescription());
+    }
 }
